-- plugins/neotest_config.lua
return {
	-- Load neotest
	{
		"nvim-neotest/neotest",
		dependencies = {
			-- For JavaScript, TypeScript (Vite)
			"marilari88/neotest-vitest",
			-- For Python
			"nvim-neotest/neotest-python",
			-- For C, C++, Rust
			"orjangj/neotest-ctest",
			"rouge8/neotest-rust",
            --For Java
            "rcasia/neotest-java"
		},
		config = function()
			local neotest = require("neotest")
			local keymap = vim.keymap.set

			-- General setup for neotest
			neotest.setup({
				adapters = {
					-- Vite Adapter for JavaScript/TypeScript
					require("neotest-vitest"),
					-- Python Adapter
					require("neotest-python"),
					-- C/C++ Adapter
					require("neotest-ctest"),
					-- Rust Adapter
					require("neotest-rust"),
                    -- Java Adapter
                    require("neotest-java"),
				},
			})

			-- Keybinding Setup
			local opts = { noremap = true, silent = true }

			-- Base Keybind for testing, starting with <leader><leader>t
			keymap("n", "<leader><leader>t", "<cmd>Neotest<cr>", opts) -- Open neotest panel

			-- Run nearest test
			keymap("n", "<leader><leader>tn", "<cmd>Neotest run nearest<cr>", opts)

			-- Run all tests in the current file
			keymap("n", "<leader><leader>tf", "<cmd>Neotest run file<cr>", opts)

			-- Run all tests in the entire project
			keymap("n", "<leader><leader>ta", "<cmd>Neotest run<cr>", opts)

			-- Stop running tests
			keymap("n", "<leader><leader>ts", "<cmd>Neotest stop<cr>", opts)

			-- Jump to next test failure
			keymap("n", "<leader><leader>tj", "<cmd>Neotest jump to failure<cr>", opts)

			-- Show test summary
			keymap("n", "<leader><leader>tsm", "<cmd>Neotest summary<cr>", opts)

			-- Toggle the Neotest panel
			keymap("n", "<leader><leader>tt", "<cmd>Neotest toggle panel<cr>", opts)

			-- Additional useful keybindings
			keymap("n", "<leader><leader>tp", "<cmd>Neotest prev<cr>", opts) -- Jump to previous test failure
			keymap("n", "<leader><leader>tnx", "<cmd>Neotest run ext<cr>", opts) -- Run test using external runner (useful for custom test setups)
		end,
	},
}
